;; Generated package description from url-http-ntlm.el  -*- no-byte-compile: t -*-
(define-package "url-http-ntlm" "2.0.5.0.20231024.31412" "NTLM authentication for the url library" '((cl-lib "0.5") (ntlm "2.1.0") (nadvice "0.3")) :commit "2c76d9491304e485a91c9d457fc25130279e1324" :authors '(("Tom Schutzer-Weissmann" . "tom.weissmann@gmail.com")) :maintainer '("Thomas Fitzsimmons" . "fitzsim@fitzsim.org") :keywords '("comm" "data" "processes" "hypermedia") :url "https://code.google.com/p/url-http-ntlm/")
